// @ts-check
import { defineConfig } from 'astro/config';
import starlight from '@astrojs/starlight';
import sidebarFr from './src/sidebars/fr/sidebar';

// https://astro.build/config
export default defineConfig({
	trailingSlash: 'always',
	vite: {
		resolve: {
			alias: {
				'@components': '/src/content/components',
				'@assets': '/src/assets'
			}
		}
	},
	integrations: [
		starlight({
			title: 'Open Source Québec',
			logo: {
				src: './src/assets/images/open-source-quebec-logo-fit.svg',
				alt: 'Open Source Québec',
				replacesTitle: true
			},
			defaultLocale: 'fr',
			customCss: [
				// Chemin relatif vers votre fichier CSS @font-face.
				'/src/fonts/font-face.css',
			],
			locales: {
				fr: {
					label: 'Français'
				}
			},
			social: { // todo: implement gitea social
				github: 'https://git.quebec',
			},
			sidebar: sidebarFr
		}),
	],
	redirects: {
		'/': {
			status: 302, // Temporary redirect
			destination: '/fr/',
		},
	},
});
